/* Reflow Oven Controller
 *
 * Copyright (C) 2020  Mario Hüttel <mario.huettel@gmx.net>
 *
 * This file is part of the Reflow Oven Controller Project.
 *
 * The reflow oven controller is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * The Reflow Oven Control Firmware is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the reflow oven controller project.
 * If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdint.h>

/**
 * @brief Init the backup ram and make it accesible
 */
void backup_ram_init();

/**
 * @brief Disable access to the backup RAM. This saves power
 */
void backup_ram_disable();

/**
 * @brief Whis function overwrites the backup RAM with 0x00
 */
void backup_ram_wipe();

/**
 * @brief Read data from the backup RAM
 * @param addr Address offset inside memory
 * @param data read 32bit data
 */
int backup_ram_get_data(uint32_t addr, uint32_t *data);

/**
 * @brief Write data structure to backup RAM
 * @param data
 * @return
 */
int backup_ram_write_data(uint32_t addr, uint32_t data);

